"use strict";

var __importDefault = this && this.__importDefault || function (mod) {
  return mod && mod.__esModule ? mod : {
    "default": mod
  };
};

Object.defineProperty(exports, "__esModule", {
  value: true
});

const rcs_core_1 = __importDefault(require("rcs-core"));

const path_1 = __importDefault(require("path"));

const json_extra_1 = __importDefault(require("json-extra"));

const minimatch_1 = __importDefault(require("minimatch"));

class Config {
  constructor() {
    this.ignorePatterns = [];
  }

  load(pathString = path_1.default.join(process.cwd(), '.rcsrc')) {
    let configObject;
    configObject = json_extra_1.default.readToObjSync(pathString);

    if (!configObject) {
      // package.json .rcs if no other config is found
      configObject = json_extra_1.default.readToObjSync(path_1.default.join(process.cwd(), 'package.json')).rcs;
    }

    if (configObject.exclude) {
      rcs_core_1.default.selectorsLibrary.setExclude(configObject.exclude);
    }

    if (configObject.reserve) {
      rcs_core_1.default.selectorsLibrary.setReserved(configObject.reserve);
    }

    if (configObject.ignore) {
      this.ignorePatterns = configObject.ignore;
    }
  }

  isIgnored(filePath) {
    return this.ignorePatterns.some(pattern => minimatch_1.default(filePath, pattern));
  }

  static getInstance() {
    if (!this.singleton) {
      this.singleton = new this();
    }

    return this.singleton;
  }

}

exports.default = Config;
module.exports = exports.default;