"use strict";

var __importDefault = this && this.__importDefault || function (mod) {
  return mod && mod.__esModule ? mod : {
    "default": mod
  };
};

Object.defineProperty(exports, "__esModule", {
  value: true
});

const fs_1 = __importDefault(require("fs"));

const rcs_core_1 = __importDefault(require("rcs-core"));

const path_1 = __importDefault(require("path"));

const glob_1 = __importDefault(require("glob"));

const assert_1 = __importDefault(require("assert"));

const saveSync_1 = __importDefault(require("../helper/saveSync"));

const replaceData_1 = __importDefault(require("./replaceData"));

const defaults_1 = __importDefault(require("./defaults"));

const Config_1 = __importDefault(require("../Config"));

const {
  fileExt,
  availableTypes,
  optionsDefault
} = defaults_1.default;

function processSync(type, pathString, opts = {}) {
  let globString;
  const options = Object.assign(Object.assign({}, optionsDefault), opts);
  assert_1.default(availableTypes.includes(type), `type must be one of the following: ${availableTypes}`);

  if (Array.isArray(pathString)) {
    globString = `{${pathString.join(',')}}`;
  } else {
    globString = pathString;
  }

  const globArray = glob_1.default.sync(globString, {
    cwd: options.cwd,
    ignore: Config_1.default.getInstance().ignorePatterns
  });
  const cssHtmlFiles = globArray.filter(file => fileExt.css.includes(path_1.default.extname(file)) || fileExt.html.includes(path_1.default.extname(file)));
  const fillLibraryFiles = type === 'auto' ? cssHtmlFiles : globArray;

  if (type === 'auto' || type === 'css' || type === 'html') {
    fillLibraryFiles.forEach(filePath => {
      const fileData = fs_1.default.readFileSync(path_1.default.join(options.cwd, filePath), 'utf8');
      const isHtml = fileExt.html.includes(path_1.default.extname(filePath));
      rcs_core_1.default.fillLibraries(fileData.toString(), {
        prefix: options.prefix,
        suffix: options.suffix,
        replaceKeyframes: options.replaceKeyframes,
        preventRandomName: options.preventRandomName,
        ignoreAttributeSelectors: options.ignoreAttributeSelectors,
        ignoreCssVariables: options.ignoreCssVariables,
        codeType: isHtml ? 'html' : 'css'
      });
    });
  }

  globArray.forEach(filePath => {
    let shouldOverwrite = options.overwrite;
    const joinedPath = path_1.default.join(options.newPath, filePath);

    if (!options.overwrite) {
      shouldOverwrite = joinedPath !== path_1.default.join(options.cwd, filePath);
    }

    const fileData = fs_1.default.readFileSync(path_1.default.join(options.cwd, filePath), 'utf8');
    const data = replaceData_1.default(type, filePath, fileData, options);
    saveSync_1.default(joinedPath, data, {
      overwrite: shouldOverwrite
    });
  });
  rcs_core_1.default.warnings.warn();
} // /processSync


exports.default = processSync;
module.exports = exports.default;